==> openGion_dev_5.9.13.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE80S.sql <==
/****************************************************************************/
/* GE80 ( FAQﾃｰﾌﾞﾙ )                                                        */
/*                                                                          */
/* Created : 2016/10/07 10:39:44                                            */
/****************************************************************************/
CREATE TABLE GE80 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      varchar           (   20 )      DEFAULT *   NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , KBFAQ        varchar           (    1 )      DEFAULT 0   NOT NULL            /*  30 FAQ区分      */
 , QANO         varchar           (   20 )                  NOT NULL            /*  40 質問番号     */
 , CDBNRUI      varchar           (   10 )                                      /*  50 分類ｺｰﾄﾞ     */
 , KNRNGUI      varchar           (  200 )                                      /*  60 関連画面ID   */
 , TITLE        varchar           (  300 )                                      /*  70 ﾀｲﾄﾙ         */
 , NAIYO        varchar           ( 4000 )                                      /*  80 内容         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  90 表示順       */
 , TAG          varchar           (  200 )                                      /* 100 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion_dev_5.9.32.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE80S.sql <==
/****************************************************************************/
/* GE80 ( FAQﾃｰﾌﾞﾙ )                                                        */
/*                                                                          */
/* Created : 2018/05/02 11:52:14                                            */
/****************************************************************************/
CREATE TABLE GE80 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      varchar           (   20 )      DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , KBFAQ        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  30 FAQ区分      */
 , QANO         varchar           (   20 )                  NOT NULL            /*  40 質問番号     */
 , CDBNRUI      varchar           (   10 )                                      /*  50 分類ｺｰﾄﾞ     */
 , KNRNGUI      varchar           (  200 )                                      /*  60 関連画面ID   */
 , TITLE        varchar           (  300 )                                      /*  70 ﾀｲﾄﾙ         */
 , NAIYO        varchar           ( 4000 )                                      /*  80 内容         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  90 表示順       */
 , TAG          varchar           (  200 )                                      /* 100 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
